@@ -8,7 +8,7 @@ use vars qw/ $VERSION @ISA/;
 
 require DynaLoader;
 
-$VERSION = '3.2.001';
+$VERSION = '4.0.001';
 
 @ISA = qw/ DynaLoader /;
 
@@ -59,22 +59,46 @@ B<Functions Supported for this class by the PerlVTK module:>
    void GenerateErrorScalarsOff ();
    void GenerateErrorScalarsOn ();
    float GetAspectRatio ();
+   float GetAspectRatioMaxValue ();
+   float GetAspectRatioMinValue ();
    int GetBoundaryVertexDeletion ();
-   const char *GetClassName();
+   const char *GetClassName ();
    int GetDegree ();
+   int GetDegreeMaxValue ();
+   int GetDegreeMinValue ();
    float GetErrorIncrement ();
+   float GetErrorIncrementMaxValue ();
+   float GetErrorIncrementMinValue ();
    float GetFeatureAngleIncrement ();
+   float GetFeatureAngleIncrementMaxValue ();
+   float GetFeatureAngleIncrementMinValue ();
    int GetGenerateErrorScalars ();
    float GetInitialError ();
+   float GetInitialErrorMaxValue ();
+   float GetInitialErrorMinValue ();
    float GetInitialFeatureAngle ();
+   float GetInitialFeatureAngleMaxValue ();
+   float GetInitialFeatureAngleMinValue ();
    float GetMaximumError ();
+   float GetMaximumErrorMaxValue ();
+   float GetMaximumErrorMinValue ();
    float GetMaximumFeatureAngle ();
+   float GetMaximumFeatureAngleMaxValue ();
+   float GetMaximumFeatureAngleMinValue ();
    int GetMaximumIterations ();
+   int GetMaximumIterationsMaxValue ();
+   int GetMaximumIterationsMinValue ();
    int GetMaximumNumberOfSquawks ();
+   int GetMaximumNumberOfSquawksMaxValue ();
+   int GetMaximumNumberOfSquawksMinValue ();
    int GetMaximumSubIterations ();
+   int GetMaximumSubIterationsMaxValue ();
+   int GetMaximumSubIterationsMinValue ();
    int GetPreserveEdges ();
    int GetPreserveTopology ();
    float GetTargetReduction ();
+   float GetTargetReductionMaxValue ();
+   float GetTargetReductionMinValue ();
    vtkDecimate *New ();
    void PreserveEdgesOff ();
    void PreserveEdgesOn ();
@@ -102,26 +126,20 @@ B<vtkDecimate Unsupported Funcs:>
 
 Functions which are not supported supported for this class by the PerlVTK module.
 
-   int BuildLoop (int ptId, unsigned short nTris, int *tris);
+   int BuildLoop (long ptId, unsigned short nTris, long *tris);
       Don't know the size of pointer arg number 3
 
-   int CanSplitLoop (vtkLocalVertexPtr fedges[2], int numVerts, vtkLocalVertexPtr verts[], int &n1, vtkLocalVertexPtr l1[], int &n2, vtkLocalVertexPtr l2[], float &ar);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
+   int CanSplitLoop (vtkLocalVertexPtr fedges[2], long numVerts, vtkLocalVertexPtr verts[], long &n1, vtkLocalVertexPtr l1[], long &n2, vtkLocalVertexPtr l2[], float &ar);
+      Don't know the size of pointer arg number 4
 
-   float InitialFeatureAnglefloat FeatureAngleIncrementfloat MaximumFeatureAngleint PreserveEdgesint BoundaryVertexDeletionfloat InitialErrorfloat ErrorIncrementfloat MaximumErrorfloat TargetReductionint MaximumIterationsint MaximumSubIterationsfloat AspectRatioint Degreeint StatsVTK_NUMBER_STATISTICS []int GenerateErrorScalarsint MaximumNumberOfSquawksint PreserveTopologyvtkIdList *NeighborsvtkVertexArray *VvtkTriArray *Tvoid CreateOutput (int numPts, int numTris, int numEliminated, vtkPointData *pd, vtkPoints *inPts);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
-
-   void EvaluateLoop (int &vtype, int &numFEdges, vtkLocalVertexPtr fedges[]);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
+   void EvaluateLoop (int &vtype, long &numFEdges, vtkLocalVertexPtr fedges[]);
+      Don't know the size of pointer arg number 2
 
    void PrintSelf (ostream &os, vtkIndent indent);
       I/O Streams not Supported yet
 
-   void SplitLoop (vtkLocalVertexPtr fedges[2], int numVerts, vtkLocalVertexPtr *verts, int &n1, vtkLocalVertexPtr *l1, int &n2, vtkLocalVertexPtr *l2);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
-
-   void Triangulate (int numVerts, vtkLocalVertexPtr verts[]);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
+   void SplitLoop (vtkLocalVertexPtr fedges[2], long numVerts, vtkLocalVertexPtr *verts, long &n1, vtkLocalVertexPtr *l1, long &n2, vtkLocalVertexPtr *l2);
+      Don't know the size of pointer arg number 4
 
 
 =cut
@@ -144,9 +162,13 @@ Inherits from StructuredPointsToPolyDataFilter
 B<Functions Supported for this class by the PerlVTK module:>
 (To find more about their use check the VTK documentation at http://www.kitware.com.)
 
-   const char *GetClassName();
+   const char *GetClassName ();
    float GetDistance ();
+   float GetDistanceMaxValue ();
+   float GetDistanceMinValue ();
    int GetIncrement ();
+   int GetIncrementMaxValue ();
+   int GetIncrementMinValue ();
    float GetValue ();
    vtkDividingCubes *New ();
    void SetDistance (float );
@@ -162,7 +184,7 @@ Functions which are not supported supported for this class by the PerlVTK module
       I/O Streams not Supported yet
 
    void SubDivide (float origin[3], int dim[3], float h[3], float values[8]);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
+      Don't know the size of pointer arg number 1
 
 
 =cut
@@ -192,13 +214,17 @@ B<Functions Supported for this class by the PerlVTK module:>
    void ComputeScalarsOff ();
    void ComputeScalarsOn ();
    void GenerateValues (int numContours, float rangeStart, float rangeEnd);
-   const char *GetClassName();
+   const char *GetClassName ();
    int GetComputeGradients ();
    int GetComputeNormals ();
    int GetComputeScalars ();
+   int *GetExecuteExtent ();
+      (Returns a 6-element Perl list)
    unsigned long GetMTime ();
    int GetNumberOfContours ();
    int GetNumberOfThreads ();
+   int GetNumberOfThreadsMaxValue ();
+   int GetNumberOfThreadsMinValue ();
    float GetValue (int i);
    vtkGridSynchronizedTemplates3D *New ();
    void SetComputeGradients (int );
@@ -215,10 +241,7 @@ B<vtkGridSynchronizedTemplates3D Unsupported Funcs:>
 Functions which are not supported supported for this class by the PerlVTK module.
 
    void GenerateValues (int numContours, float range[2]);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
-
-   int *GetExecuteExtent ();
-      Can't Handle 'int *' return type without a hint
+      Don't know the size of pointer arg number 2
 
    float *GetValues ();
       Can't Handle 'float *' return type without a hint
@@ -226,15 +249,12 @@ Functions which are not supported supported for this class by the PerlVTK module
    void GetValues (float *contourValues);
       Don't know the size of pointer arg number 1
 
-   int NumberOfThreadsvtkMultiThreader *Threaderint MinimumPieceSize[3]int ExecuteExtent[6]vtkPolyData *ThreadsVTK_MAX_THREADS []void InitializeOutput (int *ext, vtkPolyData *o);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
+   void InitializeOutput (int *ext, vtkPolyData *o);
+      Don't know the size of pointer arg number 1
 
    void PrintSelf (ostream &os, vtkIndent indent);
       I/O Streams not Supported yet
 
-   int SplitExtent (int piece, int numPieces, int *ext);
-      Don't know the size of pointer arg number 3
-
    void ThreadedExecute (int *exExt, int threadId);
       Don't know the size of pointer arg number 1
 
@@ -267,13 +287,13 @@ B<Functions Supported for this class by the PerlVTK module:>
    void ComputeScalarsOff ();
    void ComputeScalarsOn ();
    void GenerateValues (int numContours, float rangeStart, float rangeEnd);
-   const char *GetClassName();
+   const char *GetClassName ();
    int GetComputeGradients ();
    int GetComputeNormals ();
    int GetComputeScalars ();
    vtkImageData *GetInput ();
    int GetInputMemoryLimit ();
-   int ComputeScalarsint ComputeNormalsint ComputeGradientsint NeedGradientsvtkCellArray *TrianglesvtkScalars *ScalarsvtkPoints *PointsvtkNormals *NormalsvtkVectors *Gradientsint GetLocatorPoint (int cellX, int cellY, int edge);
+   int GetLocatorPoint (int cellX, int cellY, int edge);
    unsigned long GetMTime ();
    int GetNumberOfContours ();
    float GetValue (int i);
@@ -294,7 +314,7 @@ B<vtkImageMarchingCubes Unsupported Funcs:>
 Functions which are not supported supported for this class by the PerlVTK module.
 
    void GenerateValues (int numContours, float range[2]);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
+      Don't know the size of pointer arg number 2
 
    float *GetValues ();
       Can't Handle 'float *' return type without a hint
@@ -329,7 +349,7 @@ Inherits from ContourFilter
 B<Functions Supported for this class by the PerlVTK module:>
 (To find more about their use check the VTK documentation at http://www.kitware.com.)
 
-   const char *GetClassName();
+   const char *GetClassName ();
    vtkKitwareContourFilter *New ();
 
 =cut
@@ -360,7 +380,7 @@ B<Functions Supported for this class by the PerlVTK module:>
    void ComputeScalarsOn ();
    void CreateDefaultLocator ();
    void GenerateValues (int numContours, float rangeStart, float rangeEnd);
-   const char *GetClassName();
+   const char *GetClassName ();
    int GetComputeGradients ();
    int GetComputeNormals ();
    int GetComputeScalars ();
@@ -374,7 +394,6 @@ B<Functions Supported for this class by the PerlVTK module:>
    void SetComputeNormals (int );
    void SetComputeScalars (int );
    void SetLocator (vtkPointLocator *locator);
-   void SetLocator (vtkPointLocator &locator);
    void SetNumberOfContours (int number);
    void SetUseScalarTree (int );
    void SetValue (int i, float value);
@@ -387,7 +406,7 @@ B<vtkMarchingContourFilter Unsupported Funcs:>
 Functions which are not supported supported for this class by the PerlVTK module.
 
    void GenerateValues (int numContours, float range[2]);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
+      Don't know the size of pointer arg number 2
 
    float *GetValues ();
       Can't Handle 'float *' return type without a hint
@@ -427,7 +446,7 @@ B<Functions Supported for this class by the PerlVTK module:>
    void ComputeScalarsOn ();
    void CreateDefaultLocator ();
    void GenerateValues (int numContours, float rangeStart, float rangeEnd);
-   const char *GetClassName();
+   const char *GetClassName ();
    int GetComputeGradients ();
    int GetComputeNormals ();
    int GetComputeScalars ();
@@ -440,7 +459,6 @@ B<Functions Supported for this class by the PerlVTK module:>
    void SetComputeNormals (int );
    void SetComputeScalars (int );
    void SetLocator (vtkPointLocator *locator);
-   void SetLocator (vtkPointLocator &locator);
    void SetNumberOfContours (int number);
    void SetValue (int i, float value);
 
@@ -450,7 +468,7 @@ B<vtkMarchingCubes Unsupported Funcs:>
 Functions which are not supported supported for this class by the PerlVTK module.
 
    void GenerateValues (int numContours, float range[2]);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
+      Don't know the size of pointer arg number 2
 
    float *GetValues ();
       Can't Handle 'float *' return type without a hint
@@ -467,7 +485,7 @@ Functions which are not supported supported for this class by the PerlVTK module
 package Graphics::VTK::MarchingSquares;
 
 
-@Graphics::VTK::MarchingSquares::ISA = qw( Graphics::VTK::StructuredPointsToPolyDataFilter );
+@Graphics::VTK::MarchingSquares::ISA = qw( Graphics::VTK::PolyDataSource );
 
 =head1 Graphics::VTK::MarchingSquares
 
@@ -475,7 +493,7 @@ package Graphics::VTK::MarchingSquares;
 
 =item *
 
-Inherits from StructuredPointsToPolyDataFilter
+Inherits from PolyDataSource
 
 =back
 
@@ -484,17 +502,18 @@ B<Functions Supported for this class by the PerlVTK module:>
 
    void CreateDefaultLocator ();
    void GenerateValues (int numContours, float rangeStart, float rangeEnd);
-   const char *GetClassName();
+   const char *GetClassName ();
    int  *GetImageRange ();
       (Returns a 6-element Perl list)
+   vtkImageData *GetInput ();
    vtkPointLocator *GetLocator ();
    unsigned long GetMTime ();
    int GetNumberOfContours ();
    float GetValue (int i);
    vtkMarchingSquares *New ();
    void SetImageRange (int imin, int imax, int jmin, int jmax, int kmin, int kmax);
+   void SetInput (vtkImageData *input);
    void SetLocator (vtkPointLocator *locator);
-   void SetLocator (vtkPointLocator &locator);
    void SetNumberOfContours (int number);
    void SetValue (int i, float value);
 
@@ -504,7 +523,7 @@ B<vtkMarchingSquares Unsupported Funcs:>
 Functions which are not supported supported for this class by the PerlVTK module.
 
    void GenerateValues (int numContours, float range[2]);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
+      Don't know the size of pointer arg number 2
 
    float *GetValues ();
       Can't Handle 'float *' return type without a hint
@@ -539,7 +558,7 @@ Inherits from Object
 B<Functions Supported for this class by the PerlVTK module:>
 (To find more about their use check the VTK documentation at http://www.kitware.com.)
 
-   const char *GetClassName();
+   const char *GetClassName ();
    char *GetFileName ();
    char *GetLimitsFileName ();
    vtkVolumeReader *GetReader ();
@@ -587,8 +606,10 @@ B<Functions Supported for this class by the PerlVTK module:>
    void CappingOn ();
    int GetAdjustBounds ();
    float GetAdjustDistance ();
+   float GetAdjustDistanceMaxValue ();
+   float GetAdjustDistanceMinValue ();
    int GetCapping ();
-   const char *GetClassName();
+   const char *GetClassName ();
    float GetFillValue ();
    unsigned long GetMTime ();
    int GetMaximumNumberOfInterpolationSteps ();
@@ -606,7 +627,7 @@ B<Functions Supported for this class by the PerlVTK module:>
    void SetMaximumNumberOfInterpolationSteps (int );
    void SetModelBounds (float xmin, float xmax, float ymin, float ymax, float zmin, float zmax);
    void SetNumberOfInterpolationSteps (int );
-   void SetSampleDimensions (int  , int , int );
+   void SetSampleDimensions (int , int , int );
    void SetTransforms (vtkTransformCollection *);
 
 
@@ -615,16 +636,16 @@ B<vtkSweptSurface Unsupported Funcs:>
 Functions which are not supported supported for this class by the PerlVTK module.
 
    void ComputeBounds (float origin[3], float ar[3], float bbox[24]);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
+      Don't know the size of pointer arg number 1
 
    void ComputeFootprint (vtkMatrix4x4 *m, int inDim[3], float inOrigin[3], float inSpacing[3], int Indicies[6]);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
+      Don't know the size of pointer arg number 2
 
    int ComputeNumberOfSteps (vtkTransform *t1, vtkTransform *t2, float bbox[24]);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
+      Don't know the size of pointer arg number 3
 
    vtkMatrix4x4 *GetActorMatrixPointer (vtkTransform &t, float origin[3], float position[3], float orientation[3]);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
+      Don't know the size of pointer arg number 2
 
    void GetRelativePosition (vtkTransform &t, float *origin, float *position);
       Don't know the size of pointer arg number 2
@@ -635,8 +656,8 @@ Functions which are not supported supported for this class by the PerlVTK module
    void PrintSelf (ostream &os, vtkIndent indent);
       I/O Streams not Supported yet
 
-   void SampleInput (vtkMatrix4x4 *m, int inDim[3], float inOrigin[3], float inAr[3], vtkScalars *in, vtkScalars *out);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
+   void SampleInput (vtkMatrix4x4 *m, int inDim[3], float inOrigin[3], float inAr[3], vtkDataArray *in, vtkDataArray *out);
+      Don't know the size of pointer arg number 2
 
    void SetModelBounds (float  [6]);
       Method is redundant. Same as SetModelBounds( float, float, float, float, float, float)
@@ -650,7 +671,7 @@ Functions which are not supported supported for this class by the PerlVTK module
 package Graphics::VTK::SynchronizedTemplates2D;
 
 
-@Graphics::VTK::SynchronizedTemplates2D::ISA = qw( Graphics::VTK::StructuredPointsToPolyDataFilter );
+@Graphics::VTK::SynchronizedTemplates2D::ISA = qw( Graphics::VTK::PolyDataSource );
 
 =head1 Graphics::VTK::SynchronizedTemplates2D
 
@@ -658,19 +679,25 @@ package Graphics::VTK::SynchronizedTemplates2D;
 
 =item *
 
-Inherits from StructuredPointsToPolyDataFilter
+Inherits from PolyDataSource
 
 =back
 
 B<Functions Supported for this class by the PerlVTK module:>
 (To find more about their use check the VTK documentation at http://www.kitware.com.)
 
+   void ComputeScalarsOff ();
+   void ComputeScalarsOn ();
    void GenerateValues (int numContours, float rangeStart, float rangeEnd);
-   const char *GetClassName();
+   const char *GetClassName ();
+   int GetComputeScalars ();
+   vtkImageData *GetInput ();
    unsigned long GetMTime ();
    int GetNumberOfContours ();
    float GetValue (int i);
    vtkSynchronizedTemplates2D *New ();
+   void SetComputeScalars (int );
+   void SetInput (vtkImageData *input);
    void SetNumberOfContours (int number);
    void SetValue (int i, float value);
 
@@ -680,7 +707,7 @@ B<vtkSynchronizedTemplates2D Unsupported Funcs:>
 Functions which are not supported supported for this class by the PerlVTK module.
 
    void GenerateValues (int numContours, float range[2]);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
+      Don't know the size of pointer arg number 2
 
    float *GetValues ();
       Can't Handle 'float *' return type without a hint
@@ -719,15 +746,19 @@ B<Functions Supported for this class by the PerlVTK module:>
    void ComputeScalarsOff ();
    void ComputeScalarsOn ();
    void GenerateValues (int numContours, float rangeStart, float rangeEnd);
-   const char *GetClassName();
+   const char *GetClassName ();
    int GetComputeGradients ();
    int GetComputeNormals ();
    int GetComputeScalars ();
+   int *GetExecuteExtent ();
+      (Returns a 6-element Perl list)
    vtkImageData *GetInput ();
    unsigned long GetInputMemoryLimit ();
    unsigned long GetMTime ();
    int GetNumberOfContours ();
    int GetNumberOfThreads ();
+   int GetNumberOfThreadsMaxValue ();
+   int GetNumberOfThreadsMinValue ();
    float GetValue (int i);
    vtkSynchronizedTemplates3D *New ();
    void SetComputeGradients (int );
@@ -745,10 +776,7 @@ B<vtkSynchronizedTemplates3D Unsupported Funcs:>
 Functions which are not supported supported for this class by the PerlVTK module.
 
    void GenerateValues (int numContours, float range[2]);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
-
-   int *GetExecuteExtent ();
-      Can't Handle 'int *' return type without a hint
+      Don't know the size of pointer arg number 2
 
    float *GetValues ();
       Can't Handle 'float *' return type without a hint
@@ -756,8 +784,8 @@ Functions which are not supported supported for this class by the PerlVTK module
    void GetValues (float *contourValues);
       Don't know the size of pointer arg number 1
 
-   int ExecuteExtent[6]int NumberOfThreadsvtkMultiThreader *ThreadervtkPolyData *ThreadsVTK_MAX_THREADS []void InitializeOutput (int *ext, vtkPolyData *o);
-      No TCL interface is provided by VTK, so we aren't going to provide one either.
+   void InitializeOutput (int *ext, vtkPolyData *o);
+      Don't know the size of pointer arg number 1
 
    void PrintSelf (ostream &os, vtkIndent indent);
       I/O Streams not Supported yet
