@@ -6,12 +6,15 @@ use vars qw/ $VERSION /;
 
 # Load the Real Libs:
 use Graphics::VTK::Common;
+use Graphics::VTK::Filtering;
+use Graphics::VTK::Rendering;
 use Graphics::VTK::Graphics;
-use Graphics::VTK::Contrib;
 use Graphics::VTK::Imaging;
+use Graphics::VTK::IO;
+use Graphics::VTK::Hybrid;
 use Graphics::VTK::Patented;
 
-$VERSION = '3.2.001';
+$VERSION = '4.0.001';
 
 # VTK Pre-defined Constants:
 $Graphics::VTK::ABS = 9;
@@ -30,6 +33,7 @@ $Graphics::VTK::ATTRIBUTE_MODE_DEFAULT = 0;
 $Graphics::VTK::ATTRIBUTE_MODE_USE_CELL_DATA = 2;
 $Graphics::VTK::ATTRIBUTE_MODE_USE_POINT_DATA = 1;
 $Graphics::VTK::BACKGROUND_LOCATION = 0;
+$Graphics::VTK::BIG_ENDIAN = 1;
 $Graphics::VTK::BINARY = 2;
 $Graphics::VTK::BIT = 1;
 $Graphics::VTK::BIT_MAX = 1;
@@ -37,12 +41,9 @@ $Graphics::VTK::BIT_MIN = 0;
 $Graphics::VTK::BLEND_MODE_COMPOSITE = 0;
 $Graphics::VTK::BLEND_MODE_MAX_INTENSITY = 1;
 $Graphics::VTK::BLEND_MODE_MIN_INTENSITY = 2;
-$Graphics::VTK::BOUNDS_TAG = 60;
-$Graphics::VTK::BREAK_RMI_TAG = 239954;
-$Graphics::VTK::BUILD_VERSION = 0;
+$Graphics::VTK::BUILD_VERSION = 2;
 $Graphics::VTK::CELL_DATA = 0;
 $Graphics::VTK::CELL_DATA_FIELD = 2;
-$Graphics::VTK::CELL_ID_TAG = 10;
 $Graphics::VTK::CELL_MODE = 1;
 $Graphics::VTK::CELL_SIZE = 512;
 $Graphics::VTK::CHAR = 2;
@@ -55,12 +56,19 @@ $Graphics::VTK::COLOR_BY_SOURCE = 1;
 $Graphics::VTK::COLOR_BY_VECTOR = 2;
 $Graphics::VTK::COLOR_MODE_DEFAULT = 0;
 $Graphics::VTK::COLOR_MODE_LINEAR_256 = 1;
-$Graphics::VTK::COLOR_MODE_LUMINANCE = 2;
 $Graphics::VTK::COLOR_MODE_LUT = 0;
 $Graphics::VTK::COLOR_MODE_MAP_SCALARS = 1;
+$Graphics::VTK::COLOR_MODE_OFF = 4;
 $Graphics::VTK::COLOR_MODE_RANDOM_COLORS = 2;
 $Graphics::VTK::COLOR_MODE_SPECIFIED_COLOR = 1;
+$Graphics::VTK::COLOR_MODE_UNIFORM_CELL_COLOR = 1;
+$Graphics::VTK::COLOR_MODE_UNIFORM_COLOR = 3;
+$Graphics::VTK::COLOR_MODE_UNIFORM_POINT_COLOR = 2;
 $Graphics::VTK::COMPLEX_MULTIPLY = 19;
+$Graphics::VTK::COMPLEX_SCALAR_PER_ELEMENT = 10;
+$Graphics::VTK::COMPLEX_SCALAR_PER_NODE = 8;
+$Graphics::VTK::COMPLEX_VECTOR_PER_ELEMENT = 11;
+$Graphics::VTK::COMPLEX_VECTOR_PER_NODE = 9;
 $Graphics::VTK::COMPOSITE_CLASSIFY_FIRST = 0;
 $Graphics::VTK::COMPOSITE_INTERPOLATE_FIRST = 1;
 $Graphics::VTK::CONJUGATE = 18;
@@ -91,7 +99,30 @@ $Graphics::VTK::DISPLAY = 0;
 $Graphics::VTK::DIVIDE = 3;
 $Graphics::VTK::DOUBLE = 11;
 $Graphics::VTK::DOUBLE_MAX = 1;
+$Graphics::VTK::EDT_SAITO = 1;
+$Graphics::VTK::EDT_SAITO_CACHED = 0;
+$Graphics::VTK::EMPTY = 9;
 $Graphics::VTK::EMPTY_CELL = 0;
+$Graphics::VTK::ENSIGHT_6 = 0;
+$Graphics::VTK::ENSIGHT_6_BINARY = 1;
+$Graphics::VTK::ENSIGHT_BAR2 = 1;
+$Graphics::VTK::ENSIGHT_BAR3 = 2;
+$Graphics::VTK::ENSIGHT_GOLD = 2;
+$Graphics::VTK::ENSIGHT_GOLD_BINARY = 3;
+$Graphics::VTK::ENSIGHT_HEXA20 = 13;
+$Graphics::VTK::ENSIGHT_HEXA8 = 12;
+$Graphics::VTK::ENSIGHT_NSIDED = 3;
+$Graphics::VTK::ENSIGHT_PENTA15 = 15;
+$Graphics::VTK::ENSIGHT_PENTA6 = 14;
+$Graphics::VTK::ENSIGHT_POINT = 0;
+$Graphics::VTK::ENSIGHT_PYRAMID13 = 11;
+$Graphics::VTK::ENSIGHT_PYRAMID5 = 10;
+$Graphics::VTK::ENSIGHT_QUAD4 = 6;
+$Graphics::VTK::ENSIGHT_QUAD8 = 7;
+$Graphics::VTK::ENSIGHT_TETRA10 = 9;
+$Graphics::VTK::ENSIGHT_TETRA4 = 8;
+$Graphics::VTK::ENSIGHT_TRIA3 = 4;
+$Graphics::VTK::ENSIGHT_TRIA6 = 5;
 $Graphics::VTK::EXP = 7;
 $Graphics::VTK::EXTRACT_ALL_REGIONS = 5;
 $Graphics::VTK::EXTRACT_CELL_SEEDED_REGIONS = 2;
@@ -109,24 +140,22 @@ $Graphics::VTK::FLOAT = 10;
 $Graphics::VTK::FLY_CLOSEST_TRIAD = 1;
 $Graphics::VTK::FLY_OUTER_EDGES = 0;
 $Graphics::VTK::FOREGROUND_LOCATION = 1;
-$Graphics::VTK::FRAMEBUFFER_VOLUME_MAPPER = 1;
+$Graphics::VTK::GET_ARRAY_BY_ID = 0;
+$Graphics::VTK::GET_ARRAY_BY_NAME = 1;
 $Graphics::VTK::GOURAUD = 1;
 $Graphics::VTK::GRID_CUBIC = 3;
 $Graphics::VTK::GRID_LINEAR = 1;
 $Graphics::VTK::GRID_NEAREST = 0;
 $Graphics::VTK::HEXAHEDRON = 12;
 $Graphics::VTK::HOOKEDARROW_GLYPH = 11;
+$Graphics::VTK::ICP_MODE_AV = 1;
+$Graphics::VTK::ICP_MODE_RMS = 0;
+$Graphics::VTK::ID_TYPE = 12;
 $Graphics::VTK::IMAGE_BLEND_MODE_COMPOUND = 1;
 $Graphics::VTK::IMAGE_BLEND_MODE_NORMAL = 0;
 $Graphics::VTK::IMAGE_DATA = 6;
-$Graphics::VTK::IMAGE_DATA_STREAMER_BLOCK_MODE = 3;
-$Graphics::VTK::IMAGE_DATA_STREAMER_X_SLAB_MODE = 0;
-$Graphics::VTK::IMAGE_DATA_STREAMER_Y_SLAB_MODE = 1;
-$Graphics::VTK::IMAGE_DATA_STREAMER_Z_SLAB_MODE = 2;
 $Graphics::VTK::IMAGE_NON_MAXIMUM_SUPPRESSION_MAGNITUDE_INPUT = 0;
 $Graphics::VTK::IMAGE_NON_MAXIMUM_SUPPRESSION_VECTOR_INPUT = 1;
-$Graphics::VTK::IMAGE_VIEWER_LOWER_LEFT = 1;
-$Graphics::VTK::IMAGE_VIEWER_UPPER_LEFT = 0;
 $Graphics::VTK::INDEXING_BY_SCALAR = 1;
 $Graphics::VTK::INDEXING_BY_VECTOR = 2;
 $Graphics::VTK::INDEXING_OFF = 0;
@@ -148,6 +177,11 @@ $Graphics::VTK::INTERACTOR_STYLE_CAMERA_PAN = 2;
 $Graphics::VTK::INTERACTOR_STYLE_CAMERA_ROTATE = 1;
 $Graphics::VTK::INTERACTOR_STYLE_CAMERA_SPIN = 4;
 $Graphics::VTK::INTERACTOR_STYLE_CAMERA_ZOOM = 3;
+$Graphics::VTK::INTERACTOR_STYLE_IMAGE_NONE = 0;
+$Graphics::VTK::INTERACTOR_STYLE_IMAGE_PAN = 2;
+$Graphics::VTK::INTERACTOR_STYLE_IMAGE_SPIN = 4;
+$Graphics::VTK::INTERACTOR_STYLE_IMAGE_WINDOW_LEVEL = 1;
+$Graphics::VTK::INTERACTOR_STYLE_IMAGE_ZOOM = 3;
 $Graphics::VTK::INTERSECTION = 1;
 $Graphics::VTK::INVERT = 4;
 $Graphics::VTK::IV_COLUMN = 0;
@@ -159,21 +193,24 @@ $Graphics::VTK::LABEL_SCALARS = 1;
 $Graphics::VTK::LABEL_TCOORDS = 4;
 $Graphics::VTK::LABEL_TENSORS = 5;
 $Graphics::VTK::LABEL_VECTORS = 2;
+$Graphics::VTK::LANDMARK_AFFINE = 12;
 $Graphics::VTK::LANDMARK_RIGIDBODY = 6;
 $Graphics::VTK::LANDMARK_SIMILARITY = 7;
 $Graphics::VTK::LARGE_FLOAT = 1;
+$Graphics::VTK::LARGE_ID = 2147483647;
 $Graphics::VTK::LARGE_INTEGER = 2147483647;
 $Graphics::VTK::LIGHT_TYPE_CAMERA_LIGHT = 2;
 $Graphics::VTK::LIGHT_TYPE_HEADLIGHT = 1;
 $Graphics::VTK::LIGHT_TYPE_SCENE_LIGHT = 3;
 $Graphics::VTK::LINE = 3;
 $Graphics::VTK::LINEAR_INTERPOLATION = 1;
+$Graphics::VTK::LITTLE_ENDIAN = 0;
 $Graphics::VTK::LOG = 8;
 $Graphics::VTK::LOG_EVENT_LENGTH = 40;
 $Graphics::VTK::LONG = 8;
 $Graphics::VTK::LUMINANCE = 1;
 $Graphics::VTK::LUMINANCE_ALPHA = 2;
-$Graphics::VTK::MAJOR_VERSION = 3;
+$Graphics::VTK::MAJOR_VERSION = 4;
 $Graphics::VTK::MAX = 13;
 $Graphics::VTK::MAXIMIZE_OPACITY = 1;
 $Graphics::VTK::MAXIMIZE_SCALAR_VALUE = 0;
@@ -183,7 +220,6 @@ $Graphics::VTK::MAX_SPATIAL_REP_LEVEL = 24;
 $Graphics::VTK::MAX_SPHERE_RESOLUTION = 1024;
 $Graphics::VTK::MAX_SUPERQUADRIC_RESOLUTION = 1024;
 $Graphics::VTK::MAX_THREADS = 1;
-$Graphics::VTK::MAX_VIEW_RAYS_LEVEL = 4;
 $Graphics::VTK::MIL_CCIR = 2;
 $Graphics::VTK::MIL_COMPOSITE = 1;
 $Graphics::VTK::MIL_CORONA = 4;
@@ -203,13 +239,9 @@ $Graphics::VTK::MIL_RS170 = 0;
 $Graphics::VTK::MIL_SECAM = 4;
 $Graphics::VTK::MIL_YC = 2;
 $Graphics::VTK::MIN = 12;
-$Graphics::VTK::MINOR_VERSION = 2;
-$Graphics::VTK::MP_CONTROLLER_MAX_PROCESSES = 1024;
-$Graphics::VTK::MP_CONTROLLER_RMI_ARG_TAG = 315168;
-$Graphics::VTK::MP_CONTROLLER_RMI_TAG = 315167;
+$Graphics::VTK::MINOR_VERSION = 0;
 $Graphics::VTK::MULTIPLY = 2;
 $Graphics::VTK::MULTIPLYBYK = 16;
-$Graphics::VTK::MULTI_PROCESS_LOG_MAX = 1000;
 $Graphics::VTK::NAND = 3;
 $Graphics::VTK::NEAREST_INTERPOLATION = 0;
 $Graphics::VTK::NOP = 6;
@@ -220,13 +252,41 @@ $Graphics::VTK::NORMAL_EXTRUSION = 2;
 $Graphics::VTK::NOT = 5;
 $Graphics::VTK::NO_GLYPH = 0;
 $Graphics::VTK::NUMBER_STATISTICS = 12;
-$Graphics::VTK::NUM_CELLS_TAG = 40;
-$Graphics::VTK::NUM_POINTS_TAG = 30;
 $Graphics::VTK::OR = 1;
 $Graphics::VTK::ORIENT_HORIZONTAL = 0;
 $Graphics::VTK::ORIENT_VERTICAL = 1;
 $Graphics::VTK::PARAMETRIC_CURVE = 51;
 $Graphics::VTK::PARAMETRIC_SURFACE = 52;
+$Graphics::VTK::PARSER_ABSOLUTE_VALUE = 8;
+$Graphics::VTK::PARSER_ADD = 3;
+$Graphics::VTK::PARSER_ARCCOSINE = 18;
+$Graphics::VTK::PARSER_ARCSINE = 17;
+$Graphics::VTK::PARSER_ARCTANGENT = 19;
+$Graphics::VTK::PARSER_BEGIN_VARIABLES = 30;
+$Graphics::VTK::PARSER_CEILING = 10;
+$Graphics::VTK::PARSER_COSINE = 15;
+$Graphics::VTK::PARSER_DIVIDE = 6;
+$Graphics::VTK::PARSER_DOT_PRODUCT = 24;
+$Graphics::VTK::PARSER_EXPONENT = 9;
+$Graphics::VTK::PARSER_FLOOR = 11;
+$Graphics::VTK::PARSER_HYPERBOLIC_COSINE = 21;
+$Graphics::VTK::PARSER_HYPERBOLIC_SINE = 20;
+$Graphics::VTK::PARSER_HYPERBOLIC_TANGENT = 22;
+$Graphics::VTK::PARSER_IMMEDIATE = 1;
+$Graphics::VTK::PARSER_LOGARITHM = 12;
+$Graphics::VTK::PARSER_MAGNITUDE = 28;
+$Graphics::VTK::PARSER_MULTIPLY = 5;
+$Graphics::VTK::PARSER_NORMALIZE = 29;
+$Graphics::VTK::PARSER_POWER = 7;
+$Graphics::VTK::PARSER_SCALAR_MULTIPLE = 27;
+$Graphics::VTK::PARSER_SINE = 14;
+$Graphics::VTK::PARSER_SQUARE_ROOT = 13;
+$Graphics::VTK::PARSER_SUBTRACT = 4;
+$Graphics::VTK::PARSER_TANGENT = 16;
+$Graphics::VTK::PARSER_UNARY_MINUS = 2;
+$Graphics::VTK::PARSER_VECTOR_ADD = 25;
+$Graphics::VTK::PARSER_VECTOR_SUBTRACT = 26;
+$Graphics::VTK::PARSER_VECTOR_UNARY_MINUS = 23;
 $Graphics::VTK::PHONG = 2;
 $Graphics::VTK::PIECES_EXTENT = 0;
 $Graphics::VTK::PIECEWISE_FUNCTION = 5;
@@ -238,7 +298,6 @@ $Graphics::VTK::PLOT_TCOORDS = 4;
 $Graphics::VTK::PLOT_TENSORS = 5;
 $Graphics::VTK::PLOT_VECTORS = 2;
 $Graphics::VTK::POINTS = 0;
-$Graphics::VTK::POINT_COORDS_TAG = 20;
 $Graphics::VTK::POINT_DATA = 1;
 $Graphics::VTK::POINT_DATA_FIELD = 1;
 $Graphics::VTK::POINT_EXTRUSION = 3;
@@ -246,18 +305,12 @@ $Graphics::VTK::POINT_SHELL = 0;
 $Graphics::VTK::POINT_UNIFORM = 1;
 $Graphics::VTK::POLYGON = 7;
 $Graphics::VTK::POLY_DATA = 0;
-$Graphics::VTK::POLY_DATA_TAG = 50;
 $Graphics::VTK::POLY_LINE = 4;
 $Graphics::VTK::POLY_VERTEX = 2;
-$Graphics::VTK::PORT_DATA_TRANSFER_TAG = 98974;
-$Graphics::VTK::PORT_DOWN_DATA_TIME_TAG = 98970;
-$Graphics::VTK::PORT_INFORMATION_TRANSFER_TAG = 98973;
-$Graphics::VTK::PORT_NEW_DATA_TIME_TAG = 98975;
-$Graphics::VTK::PORT_TRANSFER_NEEDED_TAG = 98972;
-$Graphics::VTK::PORT_UPDATE_EXTENT_TAG = 98971;
 $Graphics::VTK::PYRAMID = 14;
 $Graphics::VTK::QUAD = 9;
-$Graphics::VTK::RAYCAST_VOLUME_MAPPER = 0;
+$Graphics::VTK::RAMP_LINEAR = 0;
+$Graphics::VTK::RAMP_SCURVE = 1;
 $Graphics::VTK::RBF_CUSTOM = 0;
 $Graphics::VTK::RBF_R = 1;
 $Graphics::VTK::RBF_R2LOGR = 2;
@@ -275,17 +328,26 @@ $Graphics::VTK::RULED_MODE_POINT_WALK = 1;
 $Graphics::VTK::RULED_MODE_RESAMPLE = 0;
 $Graphics::VTK::SCALAR_MODE_DEFAULT = 0;
 $Graphics::VTK::SCALAR_MODE_USE_CELL_DATA = 2;
+$Graphics::VTK::SCALAR_MODE_USE_CELL_FIELD_DATA = 4;
 $Graphics::VTK::SCALAR_MODE_USE_POINT_DATA = 1;
+$Graphics::VTK::SCALAR_MODE_USE_POINT_FIELD_DATA = 3;
+$Graphics::VTK::SCALAR_PER_ELEMENT = 3;
+$Graphics::VTK::SCALAR_PER_MEASURED_NODE = 6;
+$Graphics::VTK::SCALAR_PER_NODE = 0;
 $Graphics::VTK::SCALE_BY_SCALAR = 0;
 $Graphics::VTK::SCALE_BY_VECTOR = 1;
 $Graphics::VTK::SCALE_BY_VECTORCOMPONENTS = 2;
+$Graphics::VTK::SCALE_LINEAR = 0;
+$Graphics::VTK::SCALE_LOG10 = 1;
 $Graphics::VTK::SHORT = 4;
 $Graphics::VTK::SHORT_MAX = 32767;
 $Graphics::VTK::SIN = 5;
 $Graphics::VTK::SINGLE_POINT = 1;
-$Graphics::VTK::SOFTWAREBUFFER_VOLUME_MAPPER = 2;
+$Graphics::VTK::SORT_BOUNDS_CENTER = 1;
 $Graphics::VTK::SORT_BY_CELL = 1;
 $Graphics::VTK::SORT_BY_VALUE = 0;
+$Graphics::VTK::SORT_FIRST_POINT = 0;
+$Graphics::VTK::SORT_PARAMETRIC_CENTER = 2;
 $Graphics::VTK::SQR = 10;
 $Graphics::VTK::SQRT = 11;
 $Graphics::VTK::SQUARE_GLYPH = 6;
@@ -305,6 +367,8 @@ $Graphics::VTK::SURFACE = 2;
 $Graphics::VTK::TENSOR_MODE_COMPUTE_GRADIENT = 1;
 $Graphics::VTK::TENSOR_MODE_COMPUTE_STRAIN = 2;
 $Graphics::VTK::TENSOR_MODE_PASS_TENSORS = 0;
+$Graphics::VTK::TENSOR_SYMM_PER_ELEMENT = 5;
+$Graphics::VTK::TENSOR_SYMM_PER_NODE = 2;
 $Graphics::VTK::TETRA = 10;
 $Graphics::VTK::TEXTURE_QUALITY_16BIT = 16;
 $Graphics::VTK::TEXTURE_QUALITY_32BIT = 32;
@@ -317,13 +381,20 @@ $Graphics::VTK::TEXT_TOP = 2;
 $Graphics::VTK::THICKARROW_GLYPH = 10;
 $Graphics::VTK::THICKCROSS_GLYPH = 4;
 $Graphics::VTK::THREAD_RETURN_VALUE = 0;
-$Graphics::VTK::THREAD_SAFE_LOG_MAX = 1000;
 $Graphics::VTK::TIMES = 2;
 $Graphics::VTK::TOL = 1;
 $Graphics::VTK::TRIANGLE = 5;
 $Graphics::VTK::TRIANGLE_GLYPH = 5;
 $Graphics::VTK::TRIANGLE_STRIP = 6;
 $Graphics::VTK::UNCHANGED = 0;
+$Graphics::VTK::UNICAM_BUTTON_LEFT = 1;
+$Graphics::VTK::UNICAM_BUTTON_MIDDLE = 2;
+$Graphics::VTK::UNICAM_BUTTON_RIGHT = 3;
+$Graphics::VTK::UNICAM_CAM_INT_CHOOSE = 1;
+$Graphics::VTK::UNICAM_CAM_INT_DOLLY = 3;
+$Graphics::VTK::UNICAM_CAM_INT_PAN = 2;
+$Graphics::VTK::UNICAM_CAM_INT_ROT = 0;
+$Graphics::VTK::UNICAM_NONE = 0;
 $Graphics::VTK::UNION = 0;
 $Graphics::VTK::UNION_OF_MAGNITUDES = 3;
 $Graphics::VTK::UNSIGNED_CHAR = 3;
@@ -338,14 +409,7 @@ $Graphics::VTK::UNSIGNED_SHORT_MAX = 65535;
 $Graphics::VTK::UNSIGNED_SHORT_MIN = 0;
 $Graphics::VTK::UNSTRUCTURED_GRID = 4;
 $Graphics::VTK::USERDEFINED = 6;
-$Graphics::VTK::USE_CONTRIB = 1;
-$Graphics::VTK::USE_GRAPHICS = 1;
-$Graphics::VTK::USE_IMAGING = 1;
-$Graphics::VTK::USE_MESA = 1;
 $Graphics::VTK::USE_NORMAL = 1;
-$Graphics::VTK::USE_PATENTED = 1;
-$Graphics::VTK::USE_PTHREADS = 1;
-$Graphics::VTK::USE_TKWIDGET = 1;
 $Graphics::VTK::USE_VECTOR = 0;
 $Graphics::VTK::VARY_RADIUS_BY_SCALAR = 1;
 $Graphics::VTK::VARY_RADIUS_BY_VECTOR = 2;
@@ -354,6 +418,9 @@ $Graphics::VTK::VECTOR_EXTRUSION = 1;
 $Graphics::VTK::VECTOR_MODE_COMPUTE_GRADIENT = 1;
 $Graphics::VTK::VECTOR_MODE_COMPUTE_VORTICITY = 2;
 $Graphics::VTK::VECTOR_MODE_PASS_VECTORS = 0;
+$Graphics::VTK::VECTOR_PER_ELEMENT = 4;
+$Graphics::VTK::VECTOR_PER_MEASURED_NODE = 7;
+$Graphics::VTK::VECTOR_PER_NODE = 1;
 $Graphics::VTK::VECTOR_ROTATION_OFF = 2;
 $Graphics::VTK::VERTEX = 1;
 $Graphics::VTK::VERTEX_GLYPH = 1;
@@ -362,6 +429,8 @@ $Graphics::VTK::VIEWPORT = 2;
 $Graphics::VTK::VOID = 0;
 $Graphics::VTK::VOLUME_12BIT_LOWER = 2;
 $Graphics::VTK::VOLUME_12BIT_UPPER = 1;
+$Graphics::VTK::VOLUME_16BIT = 3;
+$Graphics::VTK::VOLUME_32BIT = 4;
 $Graphics::VTK::VOLUME_8BIT = 0;
 $Graphics::VTK::VOXEL = 11;
 $Graphics::VTK::VOXEL_MODE = 0;
